@@ -21,23 +21,22 @@
 
 using namespace QCA;
 
-namespace gpgQCAPlugin
-{
+namespace gpgQCAPlugin {
 
 MyOpenPGPContext::MyOpenPGPContext(QCA::Provider *p)
-	: SMSContext(p, QStringLiteral("openpgp"))
+    : SMSContext(p, QStringLiteral("openpgp"))
 {
-	// TODO
+    // TODO
 }
 
 Provider::Context *MyOpenPGPContext::clone() const
 {
-	return nullptr;
+    return nullptr;
 }
 
 MessageContext *MyOpenPGPContext::createMessage()
 {
-	return new MyMessageContext(this, provider());
+    return new MyMessageContext(this, provider());
 }
 
 } // end namespace gpgQCAPlugin
