@@ -24,8 +24,8 @@
  */
 
 #include <QTcpSocket>
+#include <QTest>
 #include <QtCrypto>
-#include <QtTest/QtTest>
 
 #ifdef QT_STATICPLUGIN
 #include "import_plugins.h"
